==> haskell-cassava-0.4.5.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.1
id: cassava-0.4.5.1-2FysAMJ6NFuERKHGvmWo1E
key: cassava-0.4.5.1-2FysAMJ6NFuERKHGvmWo1E
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: d202d078f4f49964bf1fc1c9ee4dda6f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cassava-0.4.5.1
hs-libraries: HScassava-0.4.5.1-2FysAMJ6NFuERKHGvmWo1E
depends:
    array-0.5.1.1 attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-0.4.5.1-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cassava.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cassava
version: 0.4.5.1
id: cassava-0.4.5.1-CXabyV2MEKy607ruPbuoTu
key: cassava-0.4.5.1-CXabyV2MEKy607ruPbuoTu
license: BSD3
copyright: (c) 2012 Johan Tibell
           (c) 2012 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/cassava
synopsis: A CSV parsing and encoding library
description:
    A CSV parsing and encoding library optimized for ease of use and high
    performance.
category: Text, Web, CSV
author: Johan Tibell
exposed: True
exposed-modules:
    Data.Csv Data.Csv.Builder Data.Csv.Incremental Data.Csv.Parser
    Data.Csv.Streaming
hidden-modules: Data.Csv.Conversion Data.Csv.Conversion.Internal
                Data.Csv.Encoding Data.Csv.Types Data.Csv.Util
abi: 1fb35210fba7bad00a054c61b5dfeefd
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/cassava-0.4.5.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/cassava-0.4.5.1
hs-libraries: HScassava-0.4.5.1-CXabyV2MEKy607ruPbuoTu
depends:
    array-0.5.1.1 attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 deepseq-1.4.2.0
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-cassava/html/cassava.haddock
haddock-html: /usr/share/doc/haskell-cassava/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
